==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/el.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Δραστηριότητα",
    "Personal activity feed for %s" : "Προσωπική ροή δραστηριότητας για %s",
    "Your feed URL is invalid" : "Η διεύθυνση δεν είναι έγκυρη",
    "Your settings have been updated." : "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
    "Mail" : "Ταχυδρομείο",
    "Stream" : "Ροή",
    "Activities" : "Δραστηριότητες",
    "Error loading activities" : "Σφάλμα φόρτωσης δραστηριοτήτων",
    "No activities" : "Καμία δραστηριότητα",
    "This stream will show events like additions, changes & shares" : "Σε αυτή την ροή θα εμφανιστούν γενονότα όπως προσθήκες αλλαγές και διαμοιρασμοί",
    "There are no events for this filter" : "Δεν υπάρχουν γεγονότα για αυτό το φίλτρο",
    "Activity notification" : "Ειδοποίηση δραστηριότητας",
    "All Activities" : "Όλες οι Δραστηριότητες",
    "Activities by you" : "Δραστηριότητες από εσάς",
    "Activities by others" : "Δραστηριότητες από άλλους",
    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
    "in %s" : "σε %s",
    "%s and %s" : "%s και %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s και <strong %s> %n περισσότερo</strong>","%s και <strong %s> %n περισσότερα</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s και %n περισσότερο","%s και %n περισσότερα"],
    "Hello %s," : "Καλωσήρθατε %s,",
    "You are receiving this email because the following things happened at %s" : "Λαμβάνετε αυτό το email επειδή συνέβησαν τα ακόλουθα γεγονότα στο %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* και %n επιπλέον","* και %n επιπλέον"],
    "Notifications" : "Ειδοποιήσεις",
    "List your own actions in the stream" : "Καταγράψτε τις δράσεις σας στη ροή",
    "Notify about your own actions via email" : "Ενημερωθείτε για τις δράσεις σας μέσω ηλ. ταχυδρομείο",
    "You need to set up your email address before you can receive notification emails." : "Πρέπει να ρυθμίσετε τη διεύθυνση ηλ. ταχυδρομείου σας για να μπορείτε να λαμβάνετε ειδοποιήσεις μέσω ηλ. ταχυδρομείου.",
    "Send emails:" : "Αποστολή μηνυμάτων ηλ. ταχυδρομείου:",
    "Hourly" : "Ωριαίως",
    "Daily" : "Καθημερινώς",
    "Weekly" : "Εβδομαδιαίως",
    "Activity feed" : "Ροή Δραστηριότητας",
    "Enable RSS feed" : "Ενεργοποίηση ροής RSS",
    "No activity yet" : "Καμία δραστηριότητα μέχρι τώρα.",
    "No more events to load" : "Δεν υπάρχουν άλλα γεγονότα προς φόρτωση",
    "Files" : "Αρχεία",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s και <strong class=\"has-tooltip\" title=\"%s\"> %n περισσότερο</strong>","%s και <strong class=\"has-tooltip\" title=\"%s\"> %n περισσότερα</strong>"]
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/el.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Δραστηριότητα",
    "Personal activity feed for %s" : "Προσωπική ροή δραστηριότητας για %s",
    "Your feed URL is invalid" : "Η διεύθυνση URL δεν είναι έγκυρη",
    "Your settings have been updated." : "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
    "Mail" : "Ταχυδρομείο",
    "Stream" : "Ροή",
    "Activities" : "Δραστηριότητες",
    "Error loading activities" : "Σφάλμα φόρτωσης δραστηριοτήτων",
    "No activities" : "Καμία δραστηριότητα",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Σε αυτήν τη ροή θα εμφανιστούν γενονότα όπως προσθήκες, αλλαγές και διαμοιρασμοί",
    "There are no events for this filter" : "Δεν υπάρχουν γεγονότα για αυτό το φίλτρο",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθες",
    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
    "Activity notification" : "Ειδοποίηση δραστηριότητας",
    "All Activities" : "Όλες οι Δραστηριότητες",
    "Activities by you" : "Δραστηριότητες από εσάς",
    "Activities by others" : "Δραστηριότητες από άλλους",
    "%s and %s" : "%s και %s",
    "Hello %s," : "Καλωσήρθατε %s,",
    "You are receiving this email because the following things happened at %s" : "Λαμβάνετε αυτό το email καθώς συνέβησαν τα ακόλουθα γεγονότα στο %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* και %n επιπλέον","* και %n επιπλέον"],
    "List your own actions in the stream" : "Καταγράψτε τις δράσεις σας στη ροή",
    "Notify about your own actions via email" : "Ενημερωθείτε για τις δράσεις σας μέσω ηλ. ταχυδρομείο",
    "You need to set up your email address before you can receive notification emails." : "Πρέπει να ρυθμίσετε τη διεύθυνση ηλ. ταχυδρομείου σας για να μπορείτε να λαμβάνετε ειδοποιήσεις μέσω ηλ. ταχυδρομείου.",
    "Send emails:" : "Αποστολή μηνυμάτων ηλ. ταχυδρομείου:",
    "Hourly" : "Ωριαίως",
    "Daily" : "Καθημερινώς",
    "Weekly" : "Εβδομαδιαίως",
    "Activity feed" : "Ροή Δραστηριότητας",
    "Enable RSS feed" : "Ενεργοποίηση ροής RSS",
    "No activity yet" : "Καμία δραστηριότητα μέχρι τώρα.",
    "No more events to load" : "Δεν υπάρχουν άλλα γεγονότα προς φόρτωση",
    "Files" : "Αρχεία"
},
"nplurals=2; plural=(n != 1);");
